@@ -1,17 +1,11 @@
 #!/usr/local/bin/perl
-
-eval 'exec /usr/local/bin/perl  -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-
-eval 'exec /usr/local/bin/perl  -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
 # $File: //member/autrijus/PAR/script/par.pl $ $Author: autrijus $
-# $Revision: #79 $ $Change: 7618 $ $DateTime: 2003/08/20 09:29:59 $ vim: expandtab shiftwidth=4
+# $Revision: #81 $ $Change: 8557 $ $DateTime: 2003/10/26 02:36:51 $ vim: expandtab shiftwidth=4
 
 package __par_pl;
 
 # --- This script must not use any modules at compile time ---
-#use strict;
+# use strict;
 
 =head1 NAME
 
@@ -243,9 +237,9 @@ my ($start_pos, $data_pos);
         }
         elsif ( $fullname =~ m|^/?shlib/| and defined $ENV{PAR_TEMP} ) {
             # should be moved to _tempfile()
-            $filename = "$ENV{PAR_TEMP}/$basename$ext";
+            my $filename = "$ENV{PAR_TEMP}/$basename$ext";
             outs("SHLIB: $filename\n");
-            open $out, '>', $filename or die $!;
+            open my $out, '>', $filename or die $!;
             binmode($out);
             print $out $buf;
             close $out;
@@ -399,11 +393,10 @@ if ($out) {
     seek _FH, 0, 0;
     my $loader = scalar <_FH>;
     if (!$ENV{PAR_VERBATIM} and $loader =~ /^(?:#!|\@rem)/) {
-        print OUT pod_strip($loader, $0);
-    }
-    else {
-        print OUT $loader;
+        require PAR::Filter::PodStrip;
+        PAR::Filter::PodStrip->new->apply(\$loader, $file)
     }
+    print OUT $loader;
     $/ = undef;
     # }}}
 
@@ -472,7 +465,7 @@ if ($out) {
                 $content = <FILE>;
                 close FILE;
 
-                $content = pod_strip($content, $file)
+                PAR::Filter::PodStrip->new->apply(\$content, $file)
                     if !$ENV{PAR_VERBATIM} and lc($name) =~ /\.(?:pm|ix|al)$/i;
             }
 
@@ -532,7 +525,14 @@ if ($out) {
     foreach my $member ( $zip->members ) {
         next if $member->isDirectory or !$ENV{PAR_TEMP};
         my $member_name = $member->fileName;
-        next unless $member_name =~ m{^/?shlib/(?:$Config::Config{version}/)?(?:$Config::Config{archname}/)?([^/]+)$};
+        next unless $member_name =~ m{
+            ^
+            /?shlib/
+            (?:$Config::Config{version}/)?
+            (?:$Config::Config{archname}/)?
+            ([^/]+)
+            $
+        }x;
         my $extract_name = $1;
         my $dest_name = File::Spec->catfile($ENV{PAR_TEMP}, $extract_name);
         $member->extractToFileNamed($dest_name);
@@ -575,6 +575,7 @@ sub require_modules {
     require PAR;
     require PAR::Heavy;
     require PAR::Dist;
+    require PAR::Filter::PodStrip;
 }
 
 # N.B. we set PAR_TMP_DIR and PAR_TEMP in myldr/main.c
@@ -630,38 +631,6 @@ sub _tempfile {
 
 sub outs { warn("@_\n") unless $quiet }
 
-sub pod_strip {
-    my ($pl_text, $filename) = @_;
-
-    local $^W;
-
-    my $data = '';
-    $data = $1 if $pl_text =~ s/((?:^__DATA__$).*)//ms;
-
-    my $line = 1;
-    if ($pl_text =~ /^=(?:head\d|pod|begin|item|over|for|back|end)\b/) {
-        $pl_text = "\n$pl_text";
-        $line--;
-    }
-    $pl_text =~ s{(
-	(.*?\n)
-	=(?:head\d|pod|begin|item|over|for|back|end)\b
-	.*?\n
-	(?:=cut[\t ]*[\r\n]*?|\Z)
-	(\r?\n)?
-    )}{
-	my ($pre, $post) = ($2, $3);
-        "$pre#line " . (
-	    $line += ( () = ( $1 =~ /\n/g ) )
-	) . $post;
-    }gsex;
-    $pl_text = '#line 1 "' . ($filename) . "\"\n" . $pl_text
-        if length $filename;
-    $pl_text =~ s/^#line 1 (.*\n)(#!.*\n)/$2#line 2 $1/g;
-
-    return $pl_text . $data;
-}
-
 sub init_inc {
     require Config;
     push @INC, grep defined, map $Config::Config{$_}, qw(
@@ -687,10 +656,10 @@ die $@ if $@;
 
 };
 
-$__ERROR = $@ if $@;
+$::__ERROR = $@ if $@;
 }
 
-die $__ERROR if $__ERROR;
+die $::__ERROR if $::__ERROR;
 
 1;
 
